==> django-regex-redirects-0.3.0.tar.gz: django-regex-redirects-0.3.0/regex_redirects/actions.py <==
from __future__ import unicode_literals

import csv

from django.http import HttpResponse
from django.utils import six


# Admin action for a generic "CSV Export"
# Django snippets: http://djangosnippets.org/snippets/2369/

def export_as_csv_action(description="Export selected objects as CSV file",
                         fields=None, exclude=None, header=True):
    """
    This function returns an export csv action
    'fields' and 'exclude' work like in django ModelForm
    'header' is whether or not to output the column names as the first row
    """
    def export_as_csv(modeladmin, request, queryset):
        """
        Generic csv export admin action.
        based on http://djangosnippets.org/snippets/1697/
        """
        opts = modeladmin.model._meta
        field_names = set([field.name for field in opts.fields])
        if fields:
            fieldset = set(fields)
            field_names = fields
        elif exclude:
            excludeset = set(exclude)
            field_names = field_names - excludeset

        response = HttpResponse(content_type='text/csv')
        response['Content-Disposition'] = 'attachment; filename=%s.csv' % six.text_type(opts).replace('.', '_')

        writer = csv.writer(response)
        if header:
            writer.writerow(list(field_names))
        for obj in queryset:
            writer.writerow([six.text_type(getattr(obj, field)).encode('utf-8', 'replace') for field in field_names])
        return response
    export_as_csv.short_description = description
    return export_as_csv

==> django-regex-redirects-0.4.0.tar.gz: django-regex-redirects-0.4.0/regex_redirects/actions.py <==
from __future__ import unicode_literals

import csv

from django.http import HttpResponse


# Admin action for a generic "CSV Export"
# Django snippets: http://djangosnippets.org/snippets/2369/

def export_as_csv_action(description="Export selected objects as CSV file",
                         fields=None, exclude=None, header=True):
    """
    This function returns an export csv action
    'fields' and 'exclude' work like in django ModelForm
    'header' is whether or not to output the column names as the first row
    """
    def export_as_csv(modeladmin, request, queryset):
        """
        Generic csv export admin action.
        based on http://djangosnippets.org/snippets/1697/
        """
        opts = modeladmin.model._meta
        field_names = set([field.name for field in opts.fields])
        if fields:
            fieldset = set(fields)
            field_names = fields
        elif exclude:
            excludeset = set(exclude)
            field_names = field_names - excludeset

        response = HttpResponse(content_type='text/csv')
        response['Content-Disposition'] = 'attachment; filename=%s.csv' % opts.replace('.', '_')

        writer = csv.writer(response)
        if header:
            writer.writerow(list(field_names))
        for obj in queryset:
            writer.writerow([getattr(obj, field).encode('utf-8', 'replace') for field in field_names])
        return response
    export_as_csv.short_description = description
    return export_as_csv
